@@ -1,7 +1,9 @@
 get_rd <- function(topic, package = NULL) {
   help_call <- substitute(help(t, p), list(t = topic, p = package))
   top <- eval(help_call)
-  utils:::.getHelpFile(top)
+  if (length(top) == 0) return(NULL)
+  
+  internal_f("utils", ".getHelpFile")(top)
 }
 
 # get_rd should parse Rd into a rd_file so I don't need to maintain
@@ -14,7 +16,8 @@ get_tags <- function(rd, tag) {
 }
 
 rd2rd <- function(x) {
-  paste(unlist(tools:::as.character.Rd(x)), collapse = "")
+  chr <- internal_f("tools", "as.character.Rd")(x)
+  paste(unlist(chr), collapse = "")
 }
 
 # rd_arguments(get_rd("mean"))
